@@ -985,8 +985,10 @@ class NumerousAdminClient(NumerousClient):
 
     def listen_executions(self):
         for doc in self._base_client.ListenExecutions(spm_pb2.Empty()):
-            yield json.loads(doc)
+            yield json.loads(doc.json)
 
+    def update_execution(self, update_):
+        self._base_client.UpdateExecution(spm_pb2.Json(json=json.dumps(update_)))
 
 
 
